# purerpc
Asynchronous pure Python gRPC server and client implementation using
[curio](https://github.com/dabeaz/curio) and [hyper-h2](https://github.com/python-hyper/hyper-h2)

For server example, see `misc/greeter/main.py`